compute_xi_acf_iaaft: Compute Xi-ACF for Multiple Lags (Core Engine)

View source: R/RcppExports.R

compute_xi_acf_iaaftR Documentation

Compute Xi-ACF for Multiple Lags (Core Engine)

Description

Calculates Chatterjee's Xi coefficient for multiple lags and generates IAAFT (Iterative Amplitude Adjusted Fourier Transform) surrogates to establish confidence intervals for non-linear dependence.

Usage

compute_xi_acf_iaaft(x, max_lag, n_surr)

Arguments

x

A numeric vector (time series).

max_lag

An integer specifying the maximum number of lags to compute.

n_surr

An integer specifying the number of surrogate datasets to generate.

Value

A list containing xi_original (the Xi coefficients for the original series) and xi_surrogates (a matrix of Xi coefficients for the surrogate datasets).


xiacf documentation built on April 16, 2026, 5:08 p.m.