xi_acf: Xi-ACF Test for Time Series

View source: R/xi_acf.R

xi_acfR Documentation

Xi-ACF Test for Time Series

Description

Calculates Chatterjee's Xi and the standard Autocorrelation Function (ACF) along with their respective significance thresholds.

Usage

xi_acf(x, max_lag = 20, n_surr = 100, sig_level = 0.95)

xi_test(x, max_lag = 20, n_surr = 100)

Arguments

x

A numeric vector representing the time series data.

max_lag

An integer specifying the maximum number of lags to compute.

n_surr

An integer specifying the number of surrogate datasets to generate for the IAAFT test.

sig_level

A numeric value between 0 and 1 specifying the significance level. Default is 0.95.

Value

An object of class "xi_acf" containing the computed statistics and metadata.


xiacf documentation built on April 16, 2026, 5:08 p.m.