| xi_coefficient | R Documentation |
Computes Chatterjee's rank correlation coefficient (Xi) between two numeric vectors. Ties are broken uniformly at random to ensure strict inequalities.
xi_coefficient(x, y)
x |
A numeric vector. |
y |
A numeric vector of the same length as |
A numeric scalar representing the Chatterjee's Xi coefficient.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.