| compute_xi_acf_iaaft | R Documentation |
Calculates Chatterjee's Xi coefficient for multiple lags and generates IAAFT (Iterative Amplitude Adjusted Fourier Transform) surrogates to establish confidence intervals for non-linear dependence.
compute_xi_acf_iaaft(x, max_lag, n_surr)
x |
A numeric vector (time series). |
max_lag |
An integer specifying the maximum number of lags to compute. |
n_surr |
An integer specifying the number of surrogate datasets to generate. |
A list containing xi_original (the Xi coefficients for the original series)
and xi_surrogates (a matrix of Xi coefficients for the surrogate datasets).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.