| xi_acf | R Documentation |
Calculates Chatterjee's Xi and the standard Autocorrelation Function (ACF) along with their respective significance thresholds.
xi_acf(x, max_lag = 20, n_surr = 100, sig_level = 0.95)
xi_test(x, max_lag = 20, n_surr = 100)
x |
A numeric vector representing the time series data. |
max_lag |
An integer specifying the maximum number of lags to compute. |
n_surr |
An integer specifying the number of surrogate datasets to generate for the IAAFT test. |
sig_level |
A numeric value between 0 and 1 specifying the significance level. Default is 0.95. |
An object of class "xi_acf" containing the computed statistics and metadata.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.